SystemOrganization addCategory: #'GT-Setup'!

CommandLineHandler subclass: #GTImageSetupCommandLineHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Setup'!

!GTImageSetupCommandLineHandler commentStamp: 'TudorGirba 1/25/2015 08:02' prior: 0!
The command that can be triggered to setup a image right after the GToolkit configuration is loaded in a fresh Pharo image.

Example usage in a Jenkins:
./pharo $JOB_NAME.image gtimagesetup

To use from inside the image, run:
[ [ [ 
	self new activateWithoutSaving
] ] ]!

!GTImageSetupCommandLineHandler class methodsFor: 'accessing' stamp: 'TudorGirba 3/19/2014 11:44'!
commandName
	^ 'gtimagesetup'! !

!GTImageSetupCommandLineHandler class methodsFor: 'accessing' stamp: 'TudorGirba 3/19/2014 11:45'!
description
	^ 'Sets up the image with GToolkit specific tools and settings'! !

!GTImageSetupCommandLineHandler methodsFor: 'activation' stamp: 'TudorGirba 3/20/2014 13:42'!
activate
	"self new activate"
	self activateWithoutSaving.
	Smalltalk snapshot: true andQuit: true! !

!GTImageSetupCommandLineHandler methodsFor: 'activation' stamp: 'TudorGirba 1/5/2015 16:48'!
activateWithoutSaving
	self cleanupWorld.
"	self installGLMWhitespaceTheme."
	self installFonts.
"	self installGTInspector.
"	self installGTDebuggers.
"	self installGTPlayground.
"	self flushMCCache.
	self setPreferredSettings! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 8/17/2014 05:43'!
cleanupWorld
	SystemWindow allSubInstances do: #delete.
	World color: Color white! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
flushMCCache
	MCFileBasedRepository flushAllCaches ! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/20/2014 13:44'!
installDemoFonts
	self loadFonts.
	StandardFonts 
		setAllStandardFontsTo: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		haloFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		windowTitleFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 18);
		balloonFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 12);
		codeFont: (LogicalFont familyName: 'Source Code Pro' pointSize: 14)! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 1/4/2015 20:57'!
installFonts
	StandardFonts 
		setAllStandardFontsTo: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		haloFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		windowTitleFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 14);
		balloonFont: (LogicalFont familyName: 'Source Sans Pro' pointSize: 10);
		codeFont: (LogicalFont familyName: 'Source Code Pro' pointSize: 10)! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 6/27/2014 00:21'!
installGLMWhitespaceTheme
	GLMWhitespaceTheme 
		defaultSettings: nil;
		setPreferredWorldBackground;
		beCurrent;
		setPreferredShoutColors! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'AndreiChis 1/15/2015 21:50'!
installGTDebuggers
	
	GTGenericStackDebugger registerToolsOn: Smalltalk tools.
	
	GTGenericStackDebugger registerExtraToolsOn: Smalltalk tools.
	GTGlamourDebugger registerToolsOn: Smalltalk tools.
	#GTPPDebugger asClassIfPresent: [ :ppDebugger | ppDebugger registerToolsOn: Smalltalk tools ].
	#ACGlamourDebugger asClassIfPresent: [ :acdDebugger | acdDebugger register ].
	#GTBytecodeDebugger asClassIfPresent: [ :bytecodeDebugger | bytecodeDebugger registerToolsOn: Smalltalk tools ].
	GTSUnitDebugger registerToolsOn: Smalltalk tools.
	
	GTMoldableDebugger enableDebuggerWindowDistinctColor: true! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
installGTInspector
	GTInspector registerToolsOn: Smalltalk tools ! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 3/19/2014 11:45'!
installGTPlayground
	
	GTPlayground registerToolsOn: Smalltalk tools! !

!GTImageSetupCommandLineHandler methodsFor: 'utilities' stamp: 'TudorGirba 12/7/2014 12:58'!
setPreferredSettings
	NECPreferences 
		popupShowAutomatic: false;
		expandPrefixes: true;
		popupShowWithShortcut: Character tab asShortcut.
	GTGenericStackDebugger enableStackColoring: true.
	GLMWhitespaceTheme setPreferredShoutColors.
	KMRepository reset.
	ThemeIcons current: GLMThemeIcons new! !

TestCase subclass: #GTFinalReleaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Setup'!

!GTFinalReleaseTest commentStamp: 'AndreiChis 3/25/2015 17:41' prior: 0!
I contain tests that should be executed last as they check for various memory leaks.!

!GTFinalReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 3/25/2015 17:42'!
testNoGLMWindowInstances

	self assert: GLMSystemWindow allInstances size equals: 0.! !

!GTFinalReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 3/25/2015 17:42'!
testNoInspectorInstances

	self assert: GTInspector allInstances size equals: 0! !

!GTFinalReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 3/25/2015 17:41'!
testNoPlaygroundInstances

	self assert: GTPlayground allInstances size equals: 0! !

!GTFinalReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 3/25/2015 17:42'!
testNoSpotterInstances

	self assert: GTSpotter allInstances size equals: 0.
	self assert: GTSpotterMorph allInstances size equals: 0! !

TestCase subclass: #GTReleaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Setup'!

!GTReleaseTest methodsFor: 'accessing' stamp: 'TudorGirba 2/26/2015 06:54'!
allClassesWithCustomExtensions

	^ (self allClassesWithPragma: #spotterOrder:) asSet , 
	(self allClassesWithPragma: #gtInspectorPresentationOrder:) ! !

!GTReleaseTest methodsFor: 'accessing' stamp: 'TudorGirba 2/26/2015 06:57'!
allClassesWithPragma: pragmaSymbol
	^ Object withAllSubclasses
		select: [ :eachClass | 
			"we reject the meta classes because they do not need examples"
			eachClass = eachClass theNonMetaClass and: [
				(Pragma allNamed: pragmaSymbol from: eachClass to: eachClass) notEmpty ] ]! !

!GTReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 2/19/2015 14:50'!
hasExampleMethod: aClass

	^ ((Pragma 
		allNamed: #example 
		from: aClass class
		to: aClass class),
	(Pragma 
		allNamed: #example: 
		from: aClass class
		to: aClass class)) notEmpty
		! !

!GTReleaseTest methodsFor: 'tests' stamp: 'AndreiChis 2/19/2015 14:57'!
testAllClassesWithCustomExtensionsHaveAnExample
	| classesWithCustomExtensionsAndNoExample |
	
	classesWithCustomExtensionsAndNoExample := self allClassesWithCustomExtensions select: [ :aClass |
		(self hasExampleMethod: aClass) not ].
	
	self 
		assert: classesWithCustomExtensionsAndNoExample isEmpty
		description: [ String streamContents: [ :s|
			s 
				nextPutAll: 'Found classes with custom extensions and no example methods: ';
				print: classesWithCustomExtensionsAndNoExample ]].! !
